# Fact Sheet Shape Templates
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/fact-sheet-shape-templates#overview)
  * [Template Permissions](https://help.sap.com/docs/leanix/ea/fact-sheet-shape-templates#template-permissions)
  * [Creating Custom Shape Templates](https://help.sap.com/docs/leanix/ea/fact-sheet-shape-templates#creating-custom-shape-templates)
  * [Setting a Template as Default](https://help.sap.com/docs/leanix/ea/fact-sheet-shape-templates#setting-a-template-as-default)
  * [Editing Existing Templates](https://help.sap.com/docs/leanix/ea/fact-sheet-shape-templates#editing-existing-templates)
  * [Adding Complex Custom Shapes to the Fact Sheet Shape Templates](https://help.sap.com/docs/leanix/ea/fact-sheet-shape-templates#adding-complex-custom-shapes-to-the-fact-sheet-shape-templates)
  * [Selecting Fact Sheet Shape Templates](https://help.sap.com/docs/leanix/ea/fact-sheet-shape-templates#selecting-fact-sheet-shape-templates)
  * [Using Shape Variants](https://help.sap.com/docs/leanix/ea/fact-sheet-shape-templates#using-shape-variants)
  * [Using Shapes from Other Templates](https://help.sap.com/docs/leanix/ea/fact-sheet-shape-templates#using-shapes-from-other-templates)


Create custom templates by assigning specific shapes and colors to fact sheets to match your organization's standards, or choose default standards like SAP LeanIX and Archimate 3.2 to visually represent fact sheets in diagrams.
